# Sphinx extension for documenting Talon packages

![GitHub Workflow Status](https://img.shields.io/github/workflow/status/wenkokke/talondoc/CI) ![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/wenkokke/talondoc) ![PyPI](https://img.shields.io/pypi/v/talondoc)

See <https://wen.works/talondoc/>
